import java.awt.Color;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JFrame;
import javax.swing.JPanel;

/* 
 * This program illustrates how to draw a rectangle on a JPanel and use a 
 * MouseListener.  The rectangle's dimensions are passed to Graph's constructor via an array.
 * The mouse click coordinates are used to specify the coordinates of the upper left corner
 * of the rectangle.  The rectangle's initial position are passed in as constructor parameters.
 * 
 * As the Graph class extends the JPanel class, all methods implemented in
 * JPanel are available for use.  For example, addMouseListener in Graph's
 * constructor.
 */

@SuppressWarnings("serial")
public class Graph extends JPanel implements MouseListener {
	
	// Rectangle dimensions.  Element 0 is the x-coordinate, element 1 is the y-coordinate,
	// element 2 is the width, and element 3 is the height.
	private int[] dimensions;
	
	public Graph(int[] dimensions) {
		this.dimensions = dimensions;
		addMouseListener(this);
	}
	
	public void paintComponent(Graphics g) {
		super.setBackground(Color.white);
		super.paintComponent(g);
		Graphics2D g2 = (Graphics2D) g;
		g2.setColor(Color.black);
		g2.drawRect(dimensions[0], dimensions[1], dimensions[2], dimensions[3]);
	}
	
	@Override
	public void mouseClicked(MouseEvent arg0) {
		dimensions[0] = arg0.getX();
		dimensions[1] = arg0.getY();
		System.out.println("x " + dimensions[0] + ", y " + dimensions[1]);
		// Now that the rectangle's position has changed, notify the graphics
		// subsystem that the scene should be repainted.
		repaint();
	}

	@Override
	public void mouseEntered(MouseEvent arg0) {
	}

	@Override
	public void mouseExited(MouseEvent arg0) {
	}

	@Override
	public void mousePressed(MouseEvent arg0) {
	}

	@Override
	public void mouseReleased(MouseEvent arg0) {
	}
	
	public static void main(String[] args) {
		JFrame window = new JFrame("Graph Example");
		Container pane = window.getContentPane();
		// Set the size of the content pane.
		pane.setPreferredSize(new Dimension(500, 300));
		int[] dimensions = {10, 10, 100, 20};
		Graph g = new Graph(dimensions);
		pane.add(g);
		window.pack();
		// Set the window's position
		window.setLocation(200, 200);
		window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		window.setVisible(true);
	}
}
